package com.io.yutian.elementoriginlib;

import com.io.yutian.elementoriginlib.lang.Lang;
import com.io.yutian.elementoriginlib.listener.GuiHandlerListener;
import com.io.yutian.elementoriginlib.listener.PlayerChatInputListener;
import com.io.yutian.elementoriginlib.logger.Logger;
import com.io.yutian.elementoriginlib.redis.RedisIO;
import net.byteflux.libby.*;
import net.byteflux.libby.logging.LogLevel;
import org.bukkit.plugin.java.JavaPlugin;
import org.slf4j.LoggerFactory;
import redis.clients.jedis.Jedis;

public final class ElementOriginLib extends JavaPlugin {

    private static final org.slf4j.Logger log = LoggerFactory.getLogger(ElementOriginLib.class);
    private static ElementOriginLib instance;

    private static Logger logger = Logger.getLogger(ElementOriginLib.class);

    @Override
    public void onEnable() {
        instance = this;

        loadLibraries();

        Lang.registerLangFile(this);
        Lang.reload();

        new GuiHandlerListener(this);
        new PlayerChatInputListener(this);

        logger.info("Successfully load ElementOriginLib v"+getPluginMeta().getVersion());
    }

    private void loadLibraries() {
        logger.info("Loading libraries...");
        LibraryManager libraryManager = new BukkitLibraryManager(this);
        libraryManager.addMavenCentral();
        libraryManager.setLogLevel(LogLevel.WARN);
        libraryManager.loadLibrary(Library.builder().groupId("org{}apache{}commons").artifactId("commons-compress").version("1.26.2").build());
        libraryManager.loadLibrary(Library.builder().groupId("com{}github{}luben").artifactId("zstd-jni").version("1.5.6-3").build());
        libraryManager.loadLibrary(Library.builder().groupId("com{}zaxxer").artifactId("HikariCP").version("4.0.3").build());
        libraryManager.loadLibrary(Library.builder().groupId("org{}xerial").artifactId("sqlite-jdbc").version("3.46.0.0").build());
        libraryManager.loadLibrary(Library.builder().groupId("redis{}clients").id("jedis").artifactId("jedis").version("5.1.3").build());
        logger.info("Successfully loaded libraries.");
    }

    @Override
    public void onDisable() {
    }

    public static ElementOriginLib inst() {
        return instance;
    }

}
